#ifndef NT2_INCLUDE_FUNCTIONS_NE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NE_HPP_INCLUDED

#include <nt2/operator/include/functions/ne.hpp>

#endif
